package com.zd.system.service;

import java.util.List;
import java.util.Map;

import com.zd.system.domain.SysClass;

/**
 * 班级字典Service接口
 *
 * @author zd
 * @date 2022-04-08
 */
public interface ISysClassService
{
    /**
     * 查询班级字典
     *
     * @param id 班级字典主键
     * @return 班级字典
     */
    public SysClass selectSysClassById(Long id);

    /**
     * 查询班级字典列表
     *
     * @param sysClass 班级字典
     * @return 班级字典集合
     */
    public List<SysClass> selectSysClassList(SysClass sysClass);

    /**
     * 新增班级字典
     *
     * @param sysClass 班级字典
     * @return 结果
     */
    public Map <String,Object> insertSysClass(SysClass sysClass);

    /**
     * 修改班级字典
     *
     * @param sysClass 班级字典
     * @return 结果
     */
    public int updateSysClass(SysClass sysClass);

    /**
     * 批量删除班级字典
     *
     * @param ids 需要删除的班级字典主键集合
     * @return 结果
     */
    public int deleteSysClassByIds(Long[] ids);

    /**
     * 删除班级字典信息
     *
     * @param id 班级字典主键
     * @return 结果
     */
    public int deleteSysClassById(Long id);
}
